# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class InsertDocumentRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'index': 'str',
        'cluster': 'str',
        'id': 'int',
        'doc': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}'
    }

    attribute_map = {
        'index': 'index',
        'cluster': 'cluster',
        'id': 'id',
        'doc': 'doc'
    }

    def __init__(self, index=None, cluster=None, id=None, doc=None, local_vars_configuration=None):  # noqa: E501
        """InsertDocumentRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._index = None
        self._cluster = None
        self._id = None
        self._doc = None
        self.discriminator = None

        self.index = index
        if cluster is not None:
            self.cluster = cluster
        if id is not None:
            self.id = id
        self.doc = doc

    @property
    def index(self):
        """Gets the index of this InsertDocumentRequest.  # noqa: E501

        Name of the index  # noqa: E501

        :return: The index of this InsertDocumentRequest.  # noqa: E501
        :rtype: str
        """
        return self._index
    @index.setter
    def index(self, index):
        """Sets the index of this InsertDocumentRequest.

        Name of the index  # noqa: E501

        :param index: The index of this InsertDocumentRequest.  # noqa: E501
        :type index: str
        """
        if self.local_vars_configuration.client_side_validation and index is None:  # noqa: E501
            raise ValueError("Invalid value for `index`, must not be `None`")  # noqa: E501

        self._index = index
        

    @property
    def cluster(self):
        """Gets the cluster of this InsertDocumentRequest.  # noqa: E501

        cluster name  # noqa: E501

        :return: The cluster of this InsertDocumentRequest.  # noqa: E501
        :rtype: str
        """
        return self._cluster
    @cluster.setter
    def cluster(self, cluster):
        """Sets the cluster of this InsertDocumentRequest.

        cluster name  # noqa: E501

        :param cluster: The cluster of this InsertDocumentRequest.  # noqa: E501
        :type cluster: str
        """

        self._cluster = cluster
        

    @property
    def id(self):
        """Gets the id of this InsertDocumentRequest.  # noqa: E501

        Document ID.   # noqa: E501

        :return: The id of this InsertDocumentRequest.  # noqa: E501
        :rtype: int
        """
        return self._id
    @id.setter
    def id(self, id):
        """Sets the id of this InsertDocumentRequest.

        Document ID.   # noqa: E501

        :param id: The id of this InsertDocumentRequest.  # noqa: E501
        :type id: int
        """

        self._id = id
        

    @property
    def doc(self):
        """Gets the doc of this InsertDocumentRequest.  # noqa: E501

        Object with document data   # noqa: E501

        :return: The doc of this InsertDocumentRequest.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._doc
    @doc.setter
    def doc(self, doc):
        """Sets the doc of this InsertDocumentRequest.

        Object with document data   # noqa: E501

        :param doc: The doc of this InsertDocumentRequest.  # noqa: E501
        :type doc: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        if self.local_vars_configuration.client_side_validation and doc is None:  # noqa: E501
            raise ValueError("Invalid value for `doc`, must not be `None`")  # noqa: E501

        self._doc = doc
        


    def to_dict(self):
        """Returns the model properties as a dict"""

        result = {}		
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value



        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsertDocumentRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InsertDocumentRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class MatchPhraseFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'query_phrase': 'str',
        'query_fields': 'str'
    }

    attribute_map = {
        'query_phrase': 'query_phrase',
        'query_fields': 'query_fields'
    }

    def __init__(self, query_phrase=None, query_fields=None, local_vars_configuration=None):  # noqa: E501
        """MatchPhraseFilter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._query_phrase = None
        self._query_fields = None
        self.discriminator = None

        self.query_phrase = query_phrase
        self.query_fields = query_fields

    @property
    def query_phrase(self):
        """Gets the query_phrase of this MatchPhraseFilter.  # noqa: E501


        :return: The query_phrase of this MatchPhraseFilter.  # noqa: E501
        :rtype: str
        """
        return self._query_phrase
    @query_phrase.setter
    def query_phrase(self, query_phrase):
        """Sets the query_phrase of this MatchPhraseFilter.


        :param query_phrase: The query_phrase of this MatchPhraseFilter.  # noqa: E501
        :type query_phrase: str
        """
        if self.local_vars_configuration.client_side_validation and query_phrase is None:  # noqa: E501
            raise ValueError("Invalid value for `query_phrase`, must not be `None`")  # noqa: E501

        self._query_phrase = query_phrase
        

    @property
    def query_fields(self):
        """Gets the query_fields of this MatchPhraseFilter.  # noqa: E501


        :return: The query_fields of this MatchPhraseFilter.  # noqa: E501
        :rtype: str
        """
        return self._query_fields
    @query_fields.setter
    def query_fields(self, query_fields):
        """Sets the query_fields of this MatchPhraseFilter.


        :param query_fields: The query_fields of this MatchPhraseFilter.  # noqa: E501
        :type query_fields: str
        """
        if self.local_vars_configuration.client_side_validation and query_fields is None:  # noqa: E501
            raise ValueError("Invalid value for `query_fields`, must not be `None`")  # noqa: E501

        self._query_fields = query_fields
        


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = { 'match_phrase': {self._query_fields: self._query_phrase} }




        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MatchPhraseFilter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MatchPhraseFilter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class HighlightField(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'limit': 'int',
        'limit_words': 'int',
        'limit_snippets': 'int'
    }

    attribute_map = {
        'name': 'name',
        'limit': 'limit',
        'limit_words': 'limit_words',
        'limit_snippets': 'limit_snippets'
    }

    def __init__(self, name=None, limit=256, limit_words=0, limit_snippets=0, local_vars_configuration=None):  # noqa: E501
        """HighlightField - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._limit = None
        self._limit_words = None
        self._limit_snippets = None
        self.discriminator = None

        self.name = name
        if limit is not None:
            self.limit = limit
        if limit_words is not None:
            self.limit_words = limit_words
        if limit_snippets is not None:
            self.limit_snippets = limit_snippets

    @property
    def name(self):
        """Gets the name of this HighlightField.  # noqa: E501


        :return: The name of this HighlightField.  # noqa: E501
        :rtype: str
        """
        return self._name
    @name.setter
    def name(self, name):
        """Sets the name of this HighlightField.


        :param name: The name of this HighlightField.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name
        

    @property
    def limit(self):
        """Gets the limit of this HighlightField.  # noqa: E501


        :return: The limit of this HighlightField.  # noqa: E501
        :rtype: int
        """
        return self._limit
    @limit.setter
    def limit(self, limit):
        """Sets the limit of this HighlightField.


        :param limit: The limit of this HighlightField.  # noqa: E501
        :type limit: int
        """

        self._limit = limit
        

    @property
    def limit_words(self):
        """Gets the limit_words of this HighlightField.  # noqa: E501


        :return: The limit_words of this HighlightField.  # noqa: E501
        :rtype: int
        """
        return self._limit_words
    @limit_words.setter
    def limit_words(self, limit_words):
        """Sets the limit_words of this HighlightField.


        :param limit_words: The limit_words of this HighlightField.  # noqa: E501
        :type limit_words: int
        """

        self._limit_words = limit_words
        

    @property
    def limit_snippets(self):
        """Gets the limit_snippets of this HighlightField.  # noqa: E501


        :return: The limit_snippets of this HighlightField.  # noqa: E501
        :rtype: int
        """
        return self._limit_snippets
    @limit_snippets.setter
    def limit_snippets(self, limit_snippets):
        """Sets the limit_snippets of this HighlightField.


        :param limit_snippets: The limit_snippets of this HighlightField.  # noqa: E501
        :type limit_snippets: int
        """

        self._limit_snippets = limit_snippets
        


    def to_dict(self):
        """Returns the model properties as a dict"""

        result = {}		
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        result = { result['name']: {k:v for k,v in result.items() if k != 'name' and v is not None} }


        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HighlightField):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HighlightField):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class GeoDistanceFilterLocationAnchor(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'lat': 'float',
        'lon': 'float'
    }

    attribute_map = {
        'lat': 'lat',
        'lon': 'lon'
    }

    def __init__(self, lat=None, lon=None, local_vars_configuration=None):  # noqa: E501
        """GeoDistanceFilterLocationAnchor - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._lat = None
        self._lon = None
        self.discriminator = None

        if lat is not None:
            self.lat = lat
        if lon is not None:
            self.lon = lon

    @property
    def lat(self):
        """Gets the lat of this GeoDistanceFilterLocationAnchor.  # noqa: E501

        Geo latitude of pin point in degrees  # noqa: E501

        :return: The lat of this GeoDistanceFilterLocationAnchor.  # noqa: E501
        :rtype: float
        """
        return self._lat
    @lat.setter
    def lat(self, lat):
        """Sets the lat of this GeoDistanceFilterLocationAnchor.

        Geo latitude of pin point in degrees  # noqa: E501

        :param lat: The lat of this GeoDistanceFilterLocationAnchor.  # noqa: E501
        :type lat: float
        """

        self._lat = lat
        

    @property
    def lon(self):
        """Gets the lon of this GeoDistanceFilterLocationAnchor.  # noqa: E501

        Geo longitude pf pin point in degrees  # noqa: E501

        :return: The lon of this GeoDistanceFilterLocationAnchor.  # noqa: E501
        :rtype: float
        """
        return self._lon
    @lon.setter
    def lon(self, lon):
        """Sets the lon of this GeoDistanceFilterLocationAnchor.

        Geo longitude pf pin point in degrees  # noqa: E501

        :param lon: The lon of this GeoDistanceFilterLocationAnchor.  # noqa: E501
        :type lon: float
        """

        self._lon = lon
        


    def to_dict(self):
        """Returns the model properties as a dict"""

        result = {}		
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value



        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GeoDistanceFilterLocationAnchor):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GeoDistanceFilterLocationAnchor):
            return True

        return self.to_dict() != other.to_dict()
